@@ -1,3 +1,6 @@
+from platform import python_version
+
+from PySide6 import __version__
 from PySide6.QtCore import Qt
 from PySide6.QtWidgets import QApplication
 from PySide6.QtWidgets import QLabel
@@ -12,7 +15,9 @@ def main() -> None:
     win = QWidget()
 
     layout = QVBoxLayout()
-    label = QLabel("Hello, PyQt5!")
+    label = QLabel(
+        f"Hello, PySide6!\nPySide6 ver: {__version__}\nPython ver: {python_version()}",
+    )
     label.setAlignment(Qt.AlignCenter)
     layout.addWidget(label)
 
