@@ -5,6 +5,7 @@ __all__ = ["PackMode"]
 _pack_modes = {
     "archive": ("", "压缩"),
     "debug": ("非调试", "调试"),
+    "gui": ("CONSOLE", "GUI"),
     "offline": ("在线", "离线"),
     "rebuild": ("", "重构"),
     "recursive": ("", "递归"),
@@ -18,6 +19,7 @@ class PackMode(BaseModel):
 
     archive: bool = False
     debug: bool = False
+    gui: bool = False
     offline: bool = False
     rebuild: bool = False
     recursive: bool = False
@@ -43,6 +45,7 @@ class PackMode(BaseModel):
         """重置打包模式."""
         self.archive = False
         self.debug = False
+        self.gui = False
         self.offline = False
         self.rebuild = False
         self.recursive = False
